@@ -20,18 +20,17 @@ try:
 except ImportError:
     from collections import Mapping
 
+from pip._vendor import pkg_resources
 try:
-    from pip._internal.utils.misc import get_installed_distributions
     from pip._internal.operations.freeze import FrozenRequirement
 except ImportError:
-    from pip import get_installed_distributions, FrozenRequirement
-
-from pip._vendor import pkg_resources
+    from pip import FrozenRequirement
 # inline:
-# from graphviz import backend, Digraph
+# from graphviz import Digraph
+# from graphviz import parameters
 
 
-__version__ = '2.1.0'
+__version__ = '2.2.1'
 
 
 flatten = chain.from_iterable
@@ -599,17 +598,28 @@ def dump_graphviz(tree, output_format='dot', is_reverse=False):
 
     """
     try:
-        from graphviz import backend, Digraph
+        from graphviz import Digraph
     except ImportError:
         print('graphviz is not available, but necessary for the output '
               'option. Please install it.', file=sys.stderr)
         sys.exit(1)
 
-    if output_format not in backend.FORMATS:
+    try:
+        from graphviz import parameters
+    except ImportError:
+        from graphviz import backend
+        valid_formats = backend.FORMATS
+        print('Deprecation warning! Please upgrade graphviz to version >=0.18.0 '
+              'Support for older versions will be removed in upcoming release',
+              file=sys.stderr)
+    else:
+        valid_formats = parameters.FORMATS
+
+    if output_format not in valid_formats:
         print('{0} is not a supported output format.'.format(output_format),
               file=sys.stderr)
         print('Supported formats are: {0}'.format(
-            ', '.join(sorted(backend.FORMATS))), file=sys.stderr)
+            ', '.join(sorted(valid_formats))), file=sys.stderr)
         sys.exit(1)
 
     graph = Digraph(format=output_format)
@@ -835,11 +845,33 @@ def handle_non_host_target(args):
     return None
 
 
+def get_installed_distributions(local_only=False, user_only=False):
+    try:
+        from pip._internal.metadata import get_environment
+    except ImportError:
+        # For backward compatibility with python ver. 2.7 and pip
+        # version 20.3.4 (latest pip version that works with python
+        # version 2.7)
+        from pip._internal.utils import misc
+        return misc.get_installed_distributions(
+            local_only=local_only,
+            user_only=user_only
+        )
+    else:
+        dists = get_environment(None).iter_installed_distributions(
+            local_only=local_only,
+            skip=(),
+            user_only=user_only
+        )
+        return [d._dist for d in dists]
+
+
 def main():
     args = _get_args()
     result = handle_non_host_target(args)
     if result is not None:
         return result
+
     pkgs = get_installed_distributions(local_only=args.local_only,
                                        user_only=args.user_only)
 
